@@ -92,7 +92,6 @@ get_provider_features (GoaProvider *_provider)
          GOA_PROVIDER_FEATURE_CHAT |
          GOA_PROVIDER_FEATURE_DOCUMENTS |
          GOA_PROVIDER_FEATURE_PHOTOS |
-         GOA_PROVIDER_FEATURE_FILES |
          GOA_PROVIDER_FEATURE_PRINTERS;
 }
 
@@ -267,12 +266,6 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static gboolean
-is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
-{
-  return FALSE;
-}
-
 static gboolean
 is_identity_node (GoaOAuth2Provider *provider, WebKitDOMHTMLInputElement *element)
 {
@@ -325,7 +318,6 @@ build_object (GoaProvider         *provider,
   GoaContacts *contacts;
   GoaChat *chat;
   GoaDocuments *documents;
-  GoaFiles *files;
   GoaPhotos *photos;
   GoaPrinters *printers;
   gboolean ret;
@@ -334,7 +326,6 @@ build_object (GoaProvider         *provider,
   gboolean contacts_enabled;
   gboolean chat_enabled;
   gboolean documents_enabled;
-  gboolean files_enabled;
   gboolean photos_enabled;
   gboolean printers_enabled;
   const gchar *email_address;
@@ -345,7 +336,6 @@ build_object (GoaProvider         *provider,
   contacts = NULL;
   chat = NULL;
   documents = NULL;
-  files = NULL;
   photos = NULL;
   printers = NULL;
   ret = FALSE;
@@ -494,30 +484,6 @@ build_object (GoaProvider         *provider,
         goa_object_skeleton_set_photos (object, NULL);
     }
 
-  /* Files */
-  files = goa_object_get_files (GOA_OBJECT (object));
-  files_enabled = g_key_file_get_boolean (key_file, group, "FilesEnabled", NULL);
-  if (files_enabled)
-    {
-      if (files == NULL)
-        {
-          gchar *uri_drive;
-
-          uri_drive = g_strconcat ("google-drive://", email_address, "/", NULL);
-          files = goa_files_skeleton_new ();
-          g_object_set (G_OBJECT (files),
-                        "uri", uri_drive,
-                        NULL);
-          goa_object_skeleton_set_files (object, files);
-          g_free (uri_drive);
-        }
-    }
-  else
-    {
-      if (files != NULL)
-        goa_object_skeleton_set_files (object, NULL);
-    }
-
   /* Printers */
   printers = goa_object_get_printers (GOA_OBJECT (object));
   printers_enabled = g_key_file_get_boolean (key_file, group, "PrintersEnabled", NULL);
@@ -544,7 +510,6 @@ build_object (GoaProvider         *provider,
       goa_account_set_chat_disabled (account, !chat_enabled);
       goa_account_set_documents_disabled (account, !documents_enabled);
       goa_account_set_photos_disabled (account, !photos_enabled);
-      goa_account_set_files_disabled (account, !files_enabled);
       goa_account_set_printers_disabled (account, !printers_enabled);
 
       g_signal_connect (account,
@@ -571,10 +536,6 @@ build_object (GoaProvider         *provider,
                         "notify::photos-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
                         "PhotosEnabled");
-      g_signal_connect (account,
-                        "notify::files-disabled",
-                        G_CALLBACK (goa_util_account_notify_property_cb),
-                        "FilesEnabled");
       g_signal_connect (account,
                         "notify::printers-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
@@ -585,7 +546,6 @@ build_object (GoaProvider         *provider,
 
  out:
   g_clear_object (&printers);
-  g_clear_object (&files);
   g_clear_object (&photos);
   g_clear_object (&documents);
   g_clear_object (&chat);
@@ -652,11 +612,6 @@ show_account (GoaProvider         *provider,
                                                    "photos-disabled",
                                                    _("_Photos"));
 
-  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
-                                                   NULL,
-                                                   "files-disabled",
-                                                   _("_Files"));
-
   goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "printers-disabled",
@@ -675,7 +630,6 @@ add_account_key_values (GoaOAuth2Provider  *provider,
   g_variant_builder_add (builder, "{ss}", "ChatEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "DocumentsEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PhotosEnabled", "true");
-  g_variant_builder_add (builder, "{ss}", "FilesEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PrintersEnabled", "true");
 }
 
@@ -709,7 +663,6 @@ goa_google_provider_class_init (GoaGoogleProviderClass *klass)
   oauth2_class->get_identity_sync         = get_identity_sync;
   oauth2_class->get_redirect_uri          = get_redirect_uri;
   oauth2_class->get_scope                 = get_scope;
-  oauth2_class->is_deny_node              = is_deny_node;
   oauth2_class->is_identity_node          = is_identity_node;
   oauth2_class->get_token_uri             = get_token_uri;
   oauth2_class->get_use_mobile_browser    = get_use_mobile_browser;
