@@ -21,7 +21,7 @@
 
 #include <rest/rest-proxy.h>
 #include <json-glib/json-glib.h>
-#include <webkit/webkit.h>
+#include <libsoup/soup.h>
 
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
