@@ -22,7 +22,6 @@
 
 #include <rest/rest-proxy.h>
 #include <json-glib/json-glib.h>
-#include <webkit/webkit.h>
 
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
@@ -242,7 +241,6 @@ get_identity_sync (GoaOAuth2Provider  *provider,
     }
 
  out:
-  g_clear_object (&parser);
   g_clear_error (&identity_error);
   g_clear_object (&call);
   g_clear_object (&proxy);
@@ -253,12 +251,6 @@ get_identity_sync (GoaOAuth2Provider  *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static gboolean
-is_deny_node (GoaOAuth2Provider *provider, WebKitDOMNode *node)
-{
-  return FALSE;
-}
-
 static gboolean
 is_identity_node (GoaOAuth2Provider *provider, WebKitDOMHTMLInputElement *element)
 {
@@ -470,7 +462,6 @@ goa_windows_live_provider_class_init (GoaWindowsLiveProviderClass *klass)
   oauth2_class->get_client_secret        = get_client_secret;
   oauth2_class->get_authentication_cookie = get_authentication_cookie;
   oauth2_class->get_identity_sync        = get_identity_sync;
-  oauth2_class->is_deny_node             = is_deny_node;
   oauth2_class->is_identity_node         = is_identity_node;
   oauth2_class->add_account_key_values   = add_account_key_values;
 }
